package com.bonus.material.ma.service.impl;

import java.util.List;
import com.bonus.common.core.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.bonus.material.ma.mapper.TypeLeasePriceHisMapper;
import com.bonus.material.ma.domain.TypeLeasePriceHis;
import com.bonus.material.ma.service.ITypeLeasePriceHisService;

/**
 * 机具类型历史价格Service业务层处理
 * 
 * @author xsheng
 * @date 2024-09-27
 */
@Service
public class TypeLeasePriceHisServiceImpl implements ITypeLeasePriceHisService 
{
    @Autowired
    private TypeLeasePriceHisMapper typeLeasePriceHisMapper;

    /**
     * 查询机具类型历史价格
     * 
     * @param ID 机具类型历史价格主键
     * @return 机具类型历史价格
     */
    @Override
    public TypeLeasePriceHis selectTypeLeasePriceHisByID(Long ID)
    {
        return typeLeasePriceHisMapper.selectTypeLeasePriceHisByID(ID);
    }

    /**
     * 查询机具类型历史价格列表
     * 
     * @param typeLeasePriceHis 机具类型历史价格
     * @return 机具类型历史价格
     */
    @Override
    public List<TypeLeasePriceHis> selectTypeLeasePriceHisList(TypeLeasePriceHis typeLeasePriceHis)
    {
        return typeLeasePriceHisMapper.selectTypeLeasePriceHisList(typeLeasePriceHis);
    }

    /**
     * 新增机具类型历史价格
     * 
     * @param typeLeasePriceHis 机具类型历史价格
     * @return 结果
     */
    @Override
    public int insertTypeLeasePriceHis(TypeLeasePriceHis typeLeasePriceHis)
    {
        typeLeasePriceHis.setCreateTime(DateUtils.getNowDate());
        return typeLeasePriceHisMapper.insertTypeLeasePriceHis(typeLeasePriceHis);
    }

    /**
     * 修改机具类型历史价格
     * 
     * @param typeLeasePriceHis 机具类型历史价格
     * @return 结果
     */
    @Override
    public int updateTypeLeasePriceHis(TypeLeasePriceHis typeLeasePriceHis)
    {
        typeLeasePriceHis.setUpdateTime(DateUtils.getNowDate());
        return typeLeasePriceHisMapper.updateTypeLeasePriceHis(typeLeasePriceHis);
    }

    /**
     * 批量删除机具类型历史价格
     * 
     * @param IDs 需要删除的机具类型历史价格主键
     * @return 结果
     */
    @Override
    public int deleteTypeLeasePriceHisByIDs(Long[] IDs)
    {
        return typeLeasePriceHisMapper.deleteTypeLeasePriceHisByIDs(IDs);
    }

    /**
     * 删除机具类型历史价格信息
     * 
     * @param ID 机具类型历史价格主键
     * @return 结果
     */
    @Override
    public int deleteTypeLeasePriceHisByID(Long ID)
    {
        return typeLeasePriceHisMapper.deleteTypeLeasePriceHisByID(ID);
    }
}
