package com.bonus.material.ma.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
import com.bonus.material.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.material.ma.domain.TypeLeasePriceHis;
import com.bonus.material.ma.service.ITypeLeasePriceHisService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 机具类型历史价格Controller
 * 
 * @author xsheng
 * @date 2024-09-27
 */
@Api(tags = "机具类型历史价格接口")
@RestController
@RequestMapping("/ma_type_lease_price_his")
public class TypeLeasePriceHisController extends BaseController
{
    @Autowired
    private ITypeLeasePriceHisService typeLeasePriceHisService;

    /**
     * 查询机具类型历史价格列表
     */
    @ApiOperation(value = "查询机具类型历史价格列表")
    @RequiresPermissions("ma:his:list")
    @GetMapping("/list")
    public TableDataInfo list(TypeLeasePriceHis typeLeasePriceHis)
    {
        startPage();
        List<TypeLeasePriceHis> list = typeLeasePriceHisService.selectTypeLeasePriceHisList(typeLeasePriceHis);
        return getDataTable(list);
    }

    /**
     * 导出机具类型历史价格列表
     */
    @ApiOperation(value = "导出机具类型历史价格列表")
    @PreventRepeatSubmit
    @RequiresPermissions("ma:his:export")
    @SysLog(title = "机具类型历史价格", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出机具类型历史价格")
    @PostMapping("/export")
    public void export(HttpServletResponse response, TypeLeasePriceHis typeLeasePriceHis)
    {
        List<TypeLeasePriceHis> list = typeLeasePriceHisService.selectTypeLeasePriceHisList(typeLeasePriceHis);
        ExcelUtil<TypeLeasePriceHis> util = new ExcelUtil<TypeLeasePriceHis>(TypeLeasePriceHis.class);
        util.exportExcel(response, list, "机具类型历史价格数据");
    }

    /**
     * 获取机具类型历史价格详细信息
     */
    @ApiOperation(value = "获取机具类型历史价格详细信息")
    @RequiresPermissions("ma:his:query")
    @GetMapping(value = "/{ID}")
    public AjaxResult getInfo(@PathVariable("ID") Long ID)
    {
        return success(typeLeasePriceHisService.selectTypeLeasePriceHisByID(ID));
    }

    /**
     * 新增机具类型历史价格
     */
    @ApiOperation(value = "新增机具类型历史价格")
    @PreventRepeatSubmit
    @RequiresPermissions("ma:his:add")
    @SysLog(title = "机具类型历史价格", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增机具类型历史价格")
    @PostMapping
    public AjaxResult add(@RequestBody TypeLeasePriceHis typeLeasePriceHis)
    {
        return toAjax(typeLeasePriceHisService.insertTypeLeasePriceHis(typeLeasePriceHis));
    }

    /**
     * 修改机具类型历史价格
     */
    @ApiOperation(value = "修改机具类型历史价格")
    @PreventRepeatSubmit
    @RequiresPermissions("ma:his:edit")
    @SysLog(title = "机具类型历史价格", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改机具类型历史价格")
    @PutMapping
    public AjaxResult edit(@RequestBody TypeLeasePriceHis typeLeasePriceHis)
    {
        return toAjax(typeLeasePriceHisService.updateTypeLeasePriceHis(typeLeasePriceHis));
    }

    /**
     * 删除机具类型历史价格
     */
    @ApiOperation(value = "删除机具类型历史价格")
    @PreventRepeatSubmit
    @RequiresPermissions("ma:his:remove")
    @SysLog(title = "机具类型历史价格", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除机具类型历史价格")
	@DeleteMapping("/{IDs}")
    public AjaxResult remove(@PathVariable Long[] IDs)
    {
        return toAjax(typeLeasePriceHisService.deleteTypeLeasePriceHisByIDs(IDs));
    }
}
